pub struct ServerTimings { /* private fields */ }Expand description
Tracker for server timings.
Implements IntoResponseParts, so it can be returned at the start of an axum response tuple.
Implementations
Sourceimpl ServerTimings
impl ServerTimings
pub fn new() -> Self
Sourcepub fn add_timing(&mut self, timing: Timing)
pub fn add_timing(&mut self, timing: Timing)
Add a raw timing to the internal timing list. The internal duration tracker is not updated.
Sourcepub fn record(
&mut self,
name: impl Into<Cow<'static, str>>,
desc: impl Into<Cow<'static, str>>,
)
pub fn record( &mut self, name: impl Into<Cow<'static, str>>, desc: impl Into<Cow<'static, str>>, )
Record a timing event, with a name and description. These can be string literals or normal strings. The time since the last event is recorded automatically.
Sourcepub fn record_name(&mut self, name: impl Into<Cow<'static, str>>)
pub fn record_name(&mut self, name: impl Into<Cow<'static, str>>)
Like Self::record, but without a description. Useful for conserving bandwidth.